==> koishi-target-def-v1.0.7.tar: koishi-target-def-v1.0.7/index.ts <==
import { Adapter } from 'koishi';
import _ from 'lodash';
import { RegisterSchema, SchemaProperty } from 'schemastery-gen';

@RegisterSchema()
export class ChannelTarget {
  @SchemaProperty({ description: 'Channel ID. ', required: true })
  channelId: string;
  @SchemaProperty({ description: 'Guild ID. ' })
  guildId: string;

  toDesc(): string | [string, string] {
    return this.guildId ? [this.channelId, this.guildId] : this.channelId;
  }
}

@RegisterSchema()
export class SendTarget {
  @SchemaProperty({
    description:
      'Bot identifier. eg. onebot:123456789. Will use first bot if not specified. s',
  })
  bot: string;

  @SchemaProperty({
    type: String,
    description: 'Private chat send targets. ',
    default: [],
  })
  users: string[];

  @SchemaProperty({
    type: ChannelTarget,
    description: 'Channel send targets. ',
    default: [],
  })
  channels: ChannelTarget[];

  private getBot(bots: Adapter.BotList) {
    if (this.bot) {
      return bots.get(this.bot);
    } else {
      return bots.find((bot) => bot['parentBot']?.platform !== 'onebot');
    }
  }

  async send(bots: Adapter.BotList, content: string) {
    const bot = bots.get(this.bot);
    if (!bot) {
      throw new Error(`bot ${this.bot} not found`);
    }
    return _.flatten(
      await Promise.all([
        ...this.users.map((userId) =>
          bot.sendPrivateMessage
            ? bot.sendPrivateMessage(userId, content)
            : bot.sendMessage(`@${userId}`, content),
        ),
        ...(this.channels?.length
          ? [
              bot.broadcast(
                this.channels.map((c) => c.toDesc()),
                content,
              ),
            ]
          : []),
      ]),
    );
  }
}

==> koishi-target-def-v1.1.1.tar: koishi-target-def-v1.1.1/index.ts <==
import { Adapter, Bot } from 'koishi';
import _ from 'lodash';
import { RegisterSchema, SchemaProperty } from 'schemastery-gen';

@RegisterSchema()
export class ChannelTarget {
  @SchemaProperty({ description: 'Channel ID. ', required: true })
  channelId: string;
  @SchemaProperty({ description: 'Guild ID. ' })
  guildId: string;

  toDesc(): string | [string, string] {
    return this.guildId ? [this.channelId, this.guildId] : this.channelId;
  }
}

@RegisterSchema()
export class SendTarget {
  @SchemaProperty({
    description:
      'Bot identifier. eg. onebot:123456789. Will use first bot if not specified. s',
  })
  bot: string;

  @SchemaProperty({
    type: String,
    description: 'Private chat send targets. ',
    default: [],
  })
  users: string[];

  @SchemaProperty({
    type: ChannelTarget,
    description: 'Channel send targets. ',
    default: [],
  })
  channels: ChannelTarget[];

  private getBot(bots: Adapter.BotList) {
    if (this.bot) {
      return bots.get(this.bot);
    } else {
      return bots.find((bot) => !bot['parentBot']);
    }
  }

  private isOneBotBot(bot?: Bot) {
    return (
      bot &&
      (bot.platform === 'onebot' || bot['parentBot']?.platform === 'onebot')
    );
  }

  async send(bots: Adapter.BotList, content: string) {
    const bot = this.getBot(bots);
    if (!bot) {
      throw new Error(`bot ${this.bot} not found`);
    }
    let privateContent = content;
    let channelContent = content;
    if (this.isOneBotBot(bot)) {
      content = content.replace(/,url=base64/g, ',file=base64');
      privateContent = content.replace(/,url=http/g, ',file=http'); // private should be file
      channelContent = content.replace(/,file=http/g, ',url=http'); // channel should be url
    }
    return _.flatten(
      await Promise.all([
        ...this.users.map((userId) =>
          bot.sendPrivateMessage
            ? bot.sendPrivateMessage(userId, privateContent)
            : bot.sendMessage(`@${userId}`, privateContent),
        ),
        ...(this.channels?.length
          ? [
              bot.broadcast(
                this.channels.map((c) => c.toDesc()),
                channelContent,
              ),
            ]
          : []),
      ]),
    );
  }
}
